@@ -34,6 +34,7 @@ class Client(base.Client):
         host,
         port,
         project,
+        engine,
         region_name,
         secrets_store,
         hostname_verification,
@@ -53,8 +54,6 @@ class Client(base.Client):
         self._base_url = "https://" + self._host + ":" + str(self._port)
         self._project_name = project
         self._region_name = region_name or self.DEFAULT_REGION
-        self._cert_folder_base = cert_folder
-        self._cert_folder = os.path.join(cert_folder, host, project)
 
         if api_key_value is not None:
             api_key = api_key_value
@@ -69,40 +68,59 @@ class Client(base.Client):
         project_info = self._get_project_info(self._project_name)
         self._project_id = str(project_info["projectId"])
 
-        os.makedirs(self._cert_folder, exist_ok=True)
-        credentials = self._get_credentials(self._project_id)
-        self._write_b64_cert_to_bytes(
-            str(credentials["kStore"]),
-            path=os.path.join(self._cert_folder, "keyStore.jks"),
-        )
-        self._write_b64_cert_to_bytes(
-            str(credentials["tStore"]),
-            path=os.path.join(self._cert_folder, "trustStore.jks"),
-        )
+        self._cert_key = None
+        self._cert_folder_base = None
 
-        self._cert_key = str(credentials["password"])
-        with open(os.path.join(self._cert_folder, "material_passwd"), "w") as f:
-            f.write(str(credentials["password"]))
+        if engine == "hive":
+            # On external Spark clients (Databricks, Spark Cluster),
+            # certificates need to be provided before the Spark application starts.
+            self._cert_folder_base = cert_folder
+            self._cert_folder = os.path.join(cert_folder, host, project)
+
+            os.makedirs(self._cert_folder, exist_ok=True)
+            credentials = self._get_credentials(self._project_id)
+            self._write_b64_cert_to_bytes(
+                str(credentials["kStore"]),
+                path=self._get_jks_key_store_path(),
+            )
+            self._write_b64_cert_to_bytes(
+                str(credentials["tStore"]),
+                path=self._get_jks_trust_store_path(),
+            )
+
+            self._cert_key = str(credentials["password"])
+            with open(os.path.join(self._cert_folder, "material_passwd"), "w") as f:
+                f.write(str(credentials["password"]))
 
     def _close(self):
         """Closes a client and deletes certificates."""
-        if not os.path.exists("/dbfs/"):
-            # Clean up only on AWS, on databricks certs are needed at startup time
-            self._cleanup_file(os.path.join(self._cert_folder, "keyStore.jks"))
-            self._cleanup_file(os.path.join(self._cert_folder, "trustStore.jks"))
-            self._cleanup_file(os.path.join(self._cert_folder, "material_passwd"))
+        if self._cert_folder_base is None:
+            # On external Spark clients (Databricks, Spark Cluster),
+            # certificates need to be provided before the Spark application starts.
+            return
+
+        # Clean up only on AWS
+        self._cleanup_file(self._get_jks_key_store_path())
+        self._cleanup_file(self._get_jks_trust_store_path())
+        self._cleanup_file(os.path.join(self._cert_folder, "material_passwd"))
+
         try:
             # delete project level
             os.rmdir(self._cert_folder)
             # delete host level
             os.rmdir(os.path.dirname(self._cert_folder))
             # on AWS base dir will be empty, and can be deleted otherwise raises OSError
-            # on Databricks there will still be the scripts and clients therefore raises OSError
             os.rmdir(self._cert_folder_base)
         except OSError:
             pass
         self._connected = False
 
+    def _get_jks_trust_store_path(self):
+        return os.path.join(self._cert_folder, "trustStore.jks")
+
+    def _get_jks_key_store_path(self):
+        return os.path.join(self._cert_folder, "keyStore.jks")
+
     def _get_secret(self, secrets_store, secret_key=None, api_key_file=None):
         """Returns secret value from the AWS Secrets Manager or Parameter Store.
 
