@@ -14,23 +14,37 @@
 #   limitations under the License.
 #
 
-from hsfs.engine import spark, hive
+from hsfs.engine import spark
+from hsfs.client import exceptions
 
 _engine = None
 
 
-def init(engine_type, host=None, cert_folder=None, project=None, cert_key=None):
+def init(engine_type):
     global _engine
     if not _engine:
         if engine_type == "spark":
             _engine = spark.Engine()
         elif engine_type == "hive":
-            _engine = hive.Engine(host, cert_folder, project, cert_key)
+            try:
+                from hsfs.engine import hive
+            except ImportError:
+                raise exceptions.FeatureStoreException(
+                    "Trying to instantiate Hive as engine, but 'hive' extras are "
+                    "missing in HSFS installation. Install with `pip install "
+                    "hsfs[hive]`."
+                )
+            _engine = hive.Engine()
 
 
 def get_instance():
     global _engine
     if _engine:
+        if _engine == "training":
+            raise Exception(
+                "`training` engine doesn't support this operation. "
+                "Supported engines are `'spark'` and `'hive'`."
+            )
         return _engine
     raise Exception("Couldn't find execution engine. Try reconnecting to Hopsworks.")
 
