@@ -74,6 +74,11 @@ class StorageConnector:
         """Id of the storage connector uniquely identifying it in the Feature store."""
         return self._id
 
+    @property
+    def name(self):
+        """The name of the storage connector"""
+        return self._name
+
     @property
     def connector_type(self):
         """Type of the connector. S3, JDBC or HOPSFS."""
@@ -114,9 +119,7 @@ class StorageConnector:
         arguments.
         """
         args = [arg.split("=") for arg in self._arguments.split(",")]
+        options = {a[0]: a[1] for a in args}
+        options["url"] = self._connection_string
 
-        return {
-            "url": self._connection_string,
-            "user": [arg[1] for arg in args if arg[0] == "user"][0],
-            "password": [arg[1] for arg in args if arg[0] == "password"][0],
-        }
+        return options
